# Mindsight People Control API
[![PyPI Latest Release](https://img.shields.io/pypi/v/mindsight-people-control-api.svg)](https://pypi.org/project/mindsight-people-control-api/)

Use mindsight people control functionalities in your python application.
## Instalation
```sh
pip install mindsight-people-control-api
```

# Configuration
## Environment variables
To use mindsight-people-control-api, you need to set two environment variables:
```dotenv
# ---DOTENV EXAMPLE---
MINDSIGHT_API_TOKEN= # Token to authenticate
MINDSIGHT_API_BASE_URL=https://controle.mindsight.com.br/api # Base path of your api instance
```
